#!/usr/bin/python
# encoding: utf-8
#
# Copyright (c) 2018 Dean Jackson <deanishe@deanishe.net>
#
# MIT Licence. See http://opensource.org/licenses/MIT
#
# Created on 2018-12-23
#

"""Alfred Script Filter to validate email."""

from __future__ import print_function, absolute_import

import json
import re
import sys


ICON_WARNING = ('/System/Library/CoreServices/CoreTypes.bundle/Contents/'
                'Resources/AlertCautionIcon.icns')
ICON_OK = 'icon.png'


def log(s, *args):
    """Simple STDERR logger."""
    if args:
        s = s % args
    print(s, file=sys.stderr)


def validate_email(email):
    """Check whether ``email`` is a valid email address."""
    # Very basic (and not strictly correct) email validation
    # This will (wrongly) reject valid emails with no TLD, e.g.
    # dave@localhost, but my assumption is that they ain't very
    # commonly used
    if re.match(r'[^@]+@[^@]+\.[^@]+', email):
        return True

    return False


def main():
    """Run Script Filter."""
    # user input
    query = sys.argv[1].decode('utf-8')

    # Alfred feedback
    # By default, pass input through to next action
    item = {
        'title': query,
        'subtitle': u'Send email to ' + query,
        'arg': query,
        'valid': True,
        'icon': {'path': ICON_OK},
    }

    # If input isn't a valid email address, show a warning message in
    # Alfred instead
    valid = validate_email(query)
    log('input=%r, valid=%r', query, valid)

    if not valid:
        item = {
            'title': u'Invalid email: ' + query,
            'subtitle': u'Enter a valid email address',
            'valid': False,  # this prevents the user from hitting ENTER
            'icon': {'path': ICON_WARNING},
        }

    # Send feedback to Alfred
    json.dump(dict(items=[item]), sys.stdout, indent=2)


if __name__ == '__main__':
    main()
